package com.huangge1199.ai.service;

import dev.langchain4j.data.message.*;
import dev.langchain4j.model.chat.ChatModel;
import dev.langchain4j.model.chat.response.ChatResponse;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * AiCodeHelper
 *
 * @author huangge1199
 * @since 2025/7/12 9:26:14
 */
@Service
@Slf4j
public class AiService {

    @Resource
    private ChatModel qwenChatModel;

    public String chat(String message) {
        UserMessage userMessage = UserMessage.from(message);
        ChatResponse chatResponse = qwenChatModel.chat(userMessage);
        AiMessage aiMessage = chatResponse.aiMessage();
        log.info("AI 输出：{}", aiMessage.toString());
        return aiMessage.text();
    }

    public String chatWithPicUrl(String picUrl) {
        UserMessage userMessage = UserMessage.from(
                TextContent.from("描述图片"),
                ImageContent.from(picUrl)
        );
        ChatResponse chatResponse = qwenChatModel.chat(userMessage);
        AiMessage aiMessage = chatResponse.aiMessage();
        log.info("AI 输出：{}", aiMessage.toString());
        return aiMessage.text();
    }

    private static final String SYSTEM_MESSAGE = """
            你是旅游方面的小助手，帮助用户解答旅游路线相关的问题，并给出建议。重点关注 4 个方向：
            1. 规划旅游路线
            2. 提供当地可游玩的景点
            3. 给出整个行程的计划
            4. 分享高质量的行程规划
            请用简洁易懂的语言回答，提高用户的兴趣减少用户的规划时间。
            """;

    public String chatWithSysMessage(String message) {
        SystemMessage systemMessage = SystemMessage.from(SYSTEM_MESSAGE);
        UserMessage userMessage = UserMessage.from(message);
        ChatResponse chatResponse = qwenChatModel.chat(systemMessage, userMessage);
        AiMessage aiMessage = chatResponse.aiMessage();
        log.info("AI 输出：{}", aiMessage.toString());
        return aiMessage.text();
    }
}
